package ltd.llvy.postgis.handler;

import com.fasterxml.jackson.core.JacksonException;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.io.IOException;
import org.locationtech.jts.geom.Geometry;
import org.locationtech.jts.io.ParseException;
import org.locationtech.jts.io.WKTReader;

/**
 * (GeometryDeserializer)
 *
 * @author zweiandlen
 * @since 2024/6/5 下午4:38
 */
public class GeometryDeserializer<T extends Geometry> extends JsonDeserializer<T> {
  @Override
  public T deserialize(JsonParser jsonParser, DeserializationContext deserializationContext)
      throws IOException, JacksonException {
    String wkt = jsonParser.getValueAsString();
    WKTReader wktReader = new WKTReader();
    try {
      Geometry geometry = wktReader.read(wkt);
      return (T) geometry;
    } catch (ParseException e) {
      throw new RuntimeException("解析wkt失败：" + wkt, e);
    }
  }
}
